@@ -1,4 +1,3 @@
-
 import sys
 import time
 import logging
@@ -23,9 +22,10 @@ from notification import models as notification
 # default behavior is to never wait for the lock to be available.
 LOCK_WAIT_TIMEOUT = getattr(settings, "NOTIFICATION_LOCK_WAIT_TIMEOUT", -1)
 
+
 def send_all():
     lock = FileLock("send_notices")
-
+    
     logging.debug("acquiring lock...")
     try:
         lock.acquire(LOCK_WAIT_TIMEOUT)
@@ -36,21 +36,25 @@ def send_all():
         logging.debug("waiting for the lock timed out. quitting.")
         return
     logging.debug("acquired.")
-
+    
     batches, sent = 0, 0
     start_time = time.time()
-
+    
     try:
         # nesting the try statement to be Python 2.4
         try:
             for queued_batch in NoticeQueueBatch.objects.all():
                 notices = pickle.loads(str(queued_batch.pickled_data).decode("base64"))
-                for user, label, extra_context, on_site in notices:
-                    user = User.objects.get(pk=user)
-                    logging.info("emitting notice to %s" % user)
-                    # call this once per user to be atomic and allow for logging to
-                    # accurately show how long each takes.
-                    notification.send_now([user], label, extra_context, on_site)
+                for user, label, extra_context, on_site, sender in notices:
+                    try:
+                        user = User.objects.get(pk=user)
+                        logging.info("emitting notice %s to %s" % (label, user))
+                        # call this once per user to be atomic and allow for logging to
+                        # accurately show how long each takes.
+                        notification.send_now([user], label, extra_context, on_site, sender)
+                    except User.DoesNotExist:
+                        # Ignore deleted users, just warn about them
+                        logging.warning("not emitting notice %s to user %s since it does not exist" % (label, user))
                     sent += 1
                 queued_batch.delete()
                 batches += 1
